# Matcher Rust Implement
## Usage
Many usages u can find in [test.rs](./tests/test.rs).

## Limitations
Matchers can only handle words contains no more than 32 combined words and no more than 8 repeated word.